// Package imports:

// Package imports:
import 'package:zego_express_engine/zego_express_engine.dart';

/// @nodoc
String get attributeKeyAvatar => 'avatar';

/// @nodoc
class ZegoUIKitReceiveTurnOnLocalMicrophoneEvent {
  final String fromUserID;
  final bool muteMode;

  ZegoUIKitReceiveTurnOnLocalMicrophoneEvent(this.fromUserID, this.muteMode);

  @override
  String toString() {
    return 'from user id:$fromUserID, mute mode:$muteMode';
  }
}

/// @nodoc
enum ZegoUIKitInnerSEIType {
  mixerDeviceState,
  mediaSyncInfo,
}

/// @nodoc
class ZegoUIKitReceiveSEIEvent {
  final String typeIdentifier;
  final String senderID;
  final Map<String, dynamic> sei;

  ZegoUIKitReceiveSEIEvent(this.typeIdentifier, this.senderID, this.sei);

  @override
  String toString() {
    return 'ZegoUIKitReceiveSEIEvent{'
        'senderID:$senderID, '
        'typeIdentifier:$typeIdentifier, '
        'sei:$sei, '
        '}';
  }
}

/// @nodoc
/// Stream Resource Mode
enum ZegoAudioVideoResourceMode {
  /// Default mode. The SDK will automatically select the streaming resource according to the cdnConfig parameters set by the player config and the ready-made background configuration.
  defaultMode,

  /// Playing stream only from CDN.
  onlyCDN,

  /// Playing stream only from L3.
  onlyL3,

  /// Playing stream only from RTC.
  onlyRTC,

  /// CDN Plus mode. The SDK will automatically select the streaming resource according to the network condition.
  cdnPlus,
}

typedef ZegoPresetResolution = ZegoVideoConfigPreset;

/// @nodoc
enum ZegoStreamType {
  main,
  media,
  screenSharing,
  mix,
}

/// @nodoc
extension ZegoStreamTypeExtension on ZegoStreamType {
  String get text {
    switch (this) {
      case ZegoStreamType.main:
      case ZegoStreamType.mix:
        return name;
      case ZegoStreamType.media:
        return 'player';
      case ZegoStreamType.screenSharing:
        return 'screensharing';
    }
  }

  ZegoPublishChannel get channel {
    switch (this) {
      case ZegoStreamType.main:
        return ZegoPublishChannel.Main;
      case ZegoStreamType.media:
      case ZegoStreamType.screenSharing:
      case ZegoStreamType.mix:
        return ZegoPublishChannel.Aux;
    }
  }
}

/// Audio route
enum ZegoUIKitAudioRoute {
  speaker,
  headphone,

  /// bluetooth device
  bluetooth,

  /// telephone receiver
  receiver,

  /// external USB audio device
  externalUSB,

  /// apple AirPlay
  airPlay,
}

/// Traffic control property (bitmask enumeration).
enum ZegoUIKitTrafficControlProperty {
  /// Basic (Adaptive (reduce) video bitrate)
  basic,

  /// Adaptive (reduce) video FPS
  adaptiveFPS,

  /// Adaptive (reduce) video resolution
  adaptiveResolution,

  /// Adaptive (reduce) audio bitrate
  adaptiveAudioBitrate,
}

extension ZegoUIKitTrafficControlPropertyExtension
    on ZegoUIKitTrafficControlProperty {
  int get value {
    switch (this) {
      case ZegoUIKitTrafficControlProperty.basic:
        return 0;
      case ZegoUIKitTrafficControlProperty.adaptiveFPS:
        return 1;
      case ZegoUIKitTrafficControlProperty.adaptiveResolution:
        return 1 << 1;
      case ZegoUIKitTrafficControlProperty.adaptiveAudioBitrate:
        return 1 << 2;
    }
  }
}
